"use strict";
/**
 * @file This plugin is to access classification image data from different sources. Make sure that
 * the data is conform to expectation.
 */
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
const pipcook_core_1 = require("@pipcook/pipcook-core");
const { unZipData, downloadZip } = require('../../pipcook-core/dist/index');
const glob_promise_1 = __importDefault(require("glob-promise"));
const path = __importStar(require("path"));
const assert = __importStar(require("assert"));
const imageClassRemoteDataCollect = (args) => __awaiter(void 0, void 0, void 0, function* () {
    let { url = '', } = args || {};
    assert.ok(url, 'Please specify a url of zip of your dataset');
    const fileName = url.split(path.sep)[url.split(path.sep).length - 1];
    const extention = fileName.split('.');
    if (extention[extention.length - 1] !== 'zip') {
        throw new Error('the file must be zip file');
    }
    const datasetName = extention[0];
    const saveDir = path.join(pipcook_core_1.getDatasetDir(), datasetName);
    // local file
    if (/^file:\/\/.*/.test(url)) {
        url = url.substring(7);
    }
    else {
        const targetPath = path.join(saveDir, Date.now() + '.zip');
        console.log('downloading dataset ...');
        yield downloadZip(url, targetPath);
        url = targetPath;
    }
    const imageDir = path.join(saveDir, 'images');
    console.log('unzip and collecting data...');
    yield unZipData(url, imageDir);
    const imagePaths = yield glob_promise_1.default(path.join(imageDir, '+(train|validation|test)', '*', '*.+(jpg|jpeg|png)'));
    const typeSet = new Set();
    console.log('create annotation file...');
    imagePaths.forEach((imagePath) => {
        const splitString = imagePath.split(path.sep);
        const trainType = splitString[splitString.length - 3];
        const category = splitString[splitString.length - 2];
        const imageName = splitString[splitString.length - 1];
        const annotationDir = path.join(saveDir, 'annotations', trainType);
        pipcook_core_1.createAnnotationFile(annotationDir, imageName, splitString.slice(0, splitString.length - 1).join(path.sep), category);
        typeSet.add(trainType);
    });
    if (!typeSet.has('train')) {
        throw new Error('There is no train data. Please check the folder structure');
    }
    const result = {
        trainDataPath: path.join(saveDir, 'annotations', 'train'),
    };
    if (typeSet.has('validation')) {
        result.validationDataPath = path.join(saveDir, 'annotations', 'validation');
    }
    if (typeSet.has('test')) {
        result.testDataPath = path.join(saveDir, 'annotations', 'test');
    }
    return result;
});
exports.default = imageClassRemoteDataCollect;
